@@ -41,7 +41,6 @@
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnome/libgnometypebuiltins.h>
 #include <gconf/gconf-client.h>
-#include <gtk/gtkoptionmenu.h>
 
 
 #include <libxml/tree.h>
@@ -84,6 +83,7 @@ static const struct poptOption options[] = {
 	{ "pid",         0, POPT_ARG_STRING, &popt_data.pid,          0, N_("PID of crashed program"),             N_("PID") },
 	{ "core",        0, POPT_ARG_STRING, &popt_data.core_file,    0, N_("Core file from program"),             N_("FILE") },
 	{ "include",     0, POPT_ARG_STRING, &popt_data.include_file, 0, N_("Text file to include in the report"), N_("FILE") },
+	{ "kill",        0, POPT_ARG_INT,    &popt_data.kill,         0, N_("PID of the program to kill after the report"), N_("KILL") },
 	{ NULL } 
 };
 
@@ -177,11 +177,12 @@ buddy_get_text_widget (GtkWidget *w)
 static gboolean
 update_crash_type (GtkWidget *w, gpointer data)
 {
-	CrashType new_type = GPOINTER_TO_INT (data);
 	GtkWidget *table, *box, *scrolled, *go;
+	CrashType new_type;
 
 	stop_gdb ();
-
+	
+	new_type = gtk_combo_box_get_active (GTK_COMBO_BOX (w));
 	druid_data.crash_type = new_type;
 	
 	table = GET_WIDGET ("gdb-binary-table");
@@ -446,7 +447,7 @@ init_gnome_version_stuff (void)
 	xmlDoc *doc;
 	char *xml_file;
 	xmlNode *node;
-	char *platform, *minor, *micro, *distributor, *date;
+	guchar *platform, *minor, *micro, *distributor, *date;
 
 
 	druid_data.gnome_version = g_getenv ("BUG_BUDDY_GNOME_VERSION");
@@ -465,15 +466,15 @@ init_gnome_version_stuff (void)
 	platform = minor = micro = distributor = NULL;
 	
 	for (node = xmlDocGetRootElement (doc)->children; node; node = node->next) {
-		if (!strcmp (node->name, "platform"))
+		if (!strcmp ((char *)node->name, "platform"))
 			platform = xmlNodeGetContent (node);
-		else if (!strcmp (node->name, "minor"))
+		else if (!strcmp ((char *)node->name, "minor"))
 			minor = xmlNodeGetContent (node);
-		else if (!strcmp (node->name, "micro"))
+		else if (!strcmp ((char *)node->name, "micro"))
 			micro = xmlNodeGetContent (node);
-		else if (!strcmp (node->name, "distributor"))
+		else if (!strcmp ((char *)node->name, "distributor"))
 			distributor = xmlNodeGetContent (node);
-		else if (!strcmp (node->name, "date"))
+		else if (!strcmp ((char *)node->name, "date"))
 			date = xmlNodeGetContent (node);
 	}
 	
@@ -481,10 +482,10 @@ init_gnome_version_stuff (void)
 		druid_data.gnome_platform_version = g_strdup_printf ("GNOME%s.%s.%s", platform, minor, micro);
   
 	if (distributor && *distributor)
-		druid_data.gnome_distributor = g_strdup (distributor);
+		druid_data.gnome_distributor = g_strdup ((char *)distributor);
 	
 	if (date && *date)
-		druid_data.gnome_date = g_strdup (date);
+		druid_data.gnome_date = g_strdup ((char *)date);
 
 	xmlFree (platform);
 	xmlFree (minor);
@@ -499,7 +500,8 @@ init_gnome_version_stuff (void)
 static void
 init_ui (void)
 {
-	GtkWidget *w, *m;
+	GtkWidget *w;
+	GtkListStore *store;
 	char *s;
 	const char **sp;
 	int i;
@@ -526,9 +528,11 @@ init_ui (void)
 				     "Please use the --appname command line "
 				     "argument instead."));
 	}
-	buddy_set_text ("gdb-binary-entry", s);
-	if (s)
+	if (s) {
+		buddy_set_text ("gdb-binary-entry", s);
+		druid_data.appname = s;
 		have_appname = TRUE;
+	}
 
 	s = popt_data.pid;
 	if (!s) {
@@ -559,20 +563,21 @@ init_ui (void)
 	/* package version */
 	druid_data.version = popt_data.package_ver;
 
-        /* init some ex-radio buttons */
-	m = gtk_menu_new ();
-	for (i = 0; crash_type[i]; i++) {
-		w = gtk_menu_item_new_with_label (_(crash_type[i]));
-		g_signal_connect (G_OBJECT (w), "activate",
-				  G_CALLBACK (update_crash_type),
-				  GINT_TO_POINTER (i));
-		gtk_widget_show (w);
-		gtk_menu_shell_append (GTK_MENU_SHELL (m), w);
+	if (popt_data.kill) {
+		druid_data.kill = popt_data.kill;
 	}
+
+        /* init some ex-radio buttons */
 	w = GET_WIDGET ("gdb-option");
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (w), m);
-	gtk_option_menu_set_history (GTK_OPTION_MENU (w), druid_data.crash_type);
-	update_crash_type (NULL, GINT_TO_POINTER (druid_data.crash_type));
+	store = (GtkListStore *) gtk_combo_box_get_model (GTK_COMBO_BOX (w));
+	gtk_list_store_clear (store);
+	for (i = 0; crash_type[i]; i++) {
+		gtk_combo_box_append_text (GTK_COMBO_BOX (w), _(crash_type[i]));
+	}
+	g_signal_connect (G_OBJECT (w), "changed", 
+			  G_CALLBACK (update_crash_type), NULL);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (w), druid_data.crash_type);
+	update_crash_type (w, GINT_TO_POINTER (druid_data.crash_type));
 
 	gnome_window_icon_set_from_default (GTK_WINDOW (GET_WIDGET ("druid-window")));
 
@@ -634,6 +639,8 @@ delete_me (GtkWidget *w, GdkEventAny *evt, gpointer data)
                 gconf_client_set_int (conf_client, "/apps/bug-buddy/last_update_check",
 				      time(NULL), NULL);
 	}
+	g_free (druid_data.severity);
+	g_free (druid_data.version);
 	gtk_main_quit ();
 	return FALSE;
 }
@@ -655,6 +662,9 @@ main (int argc, char *argv[])
 	memset (&popt_data,  0, sizeof (popt_data));
 
 	druid_data.crash_type = CRASH_NONE;
+	druid_data.bug_type = BUG_WRONG;
+	druid_data.severity = NULL;
+	druid_data.version = NULL;
 	druid_data.state = -1;
 
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
@@ -691,12 +701,11 @@ main (int argc, char *argv[])
 	}
 	g_free (s);	
 
-	druid_set_state (STATE_INTRO);
-
 	init_gnome_version_stuff ();
 	init_ui ();
-
 	load_bugzillas ();
+
+
 	if (druid_data.need_to_download) {
 		int response;
 		if (gtk_dialog_run (GTK_DIALOG (GET_WIDGET ("update-dialog"))) == GTK_RESPONSE_OK) {
@@ -720,16 +729,15 @@ main (int argc, char *argv[])
 	}
 
 	load_bugzilla_xml ();
-
-	gtk_widget_show (GET_WIDGET ("druid-window"));
-
 	load_applications ();
+	products_list_load ();
 
 	if (druid_data.bug_type == BUG_CRASH)
 		start_gdb ();
+	else
+		druid_set_state (STATE_INTRO);
 
-	products_list_load ();
-
+	gtk_widget_show (GET_WIDGET ("druid-window"));
 	gtk_main ();
 
 	return 0;
